﻿/*
 * FCKeditor - The text editor for Internet - http://www.fckeditor.net
 * Copyright (C) 2003-2008 Frederico Caldeira Knabben
 *
 * == BEGIN LICENSE ==
 *
 * Licensed under the terms of any of the following licenses at your
 * choice:
 *
 *  - GNU General Public License Version 2 or later (the "GPL")
 *    http://www.gnu.org/licenses/gpl.html
 *
 *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
 *    http://www.gnu.org/licenses/lgpl.html
 *
 *  - Mozilla Public License Version 1.1 or later (the "MPL")
 *    http://www.mozilla.org/MPL/MPL-1.1.html
 *
 * == END LICENSE ==
 *
 * Italian language file.
 */

var FCKLang =
{
// Language direction : "ltr" (left to right) or "rtl" (right to left).
Dir					: "ltr",

ToolbarCollapse		: "Nascondi la barra degli strumenti",
ToolbarExpand		: "Mostra la barra degli strumenti",

// Toolbar Items and Context Menu
Save				: "Salva",
NewPage				: "Nuova pagina vuota",
Preview				: "Anteprima",
Cut					: "Taglia",
Copy				: "Copia",
Paste				: "Incolla",
PasteText			: "Incolla come testo semplice",
PasteWord			: "Incolla da Word",
Print				: "Stampa",
SelectAll			: "Seleziona tutto",
RemoveFormat		: "Elimina formattazione",
InsertLinkLbl		: "Collegamento",
InsertLink			: "Inserisci/Modifica collegamento",
RemoveLink			: "Elimina collegamento",
VisitLink			: "Open Link",	//MISSING
Anchor				: "Inserisci/Modifica Ancora",
AnchorDelete		: "Rimuovi Ancora",
InsertImageLbl		: "Immagine",
InsertImage			: "Inserisci/Modifica immagine",
InsertFlashLbl		: "Oggetto Flash",
InsertFlash			: "Inserisci/Modifica Oggetto Flash",
InsertTableLbl		: "Tabella",
InsertTable			: "Inserisci/Modifica tabella",
InsertLineLbl		: "Riga orizzontale",
InsertLine			: "Inserisci riga orizzontale",
InsertSpecialCharLbl: "Caratteri speciali",
InsertSpecialChar	: "Inserisci carattere speciale",
InsertSmileyLbl		: "Emoticon",
InsertSmiley		: "Inserisci emoticon",
About				: "Informazioni su FCKeditor",
Bold				: "Grassetto",
Italic				: "Corsivo",
Underline			: "Sottolineato",
StrikeThrough		: "Barrato",
Subscript			: "Pedice",
Superscript			: "Apice",
LeftJustify			: "Allinea a sinistra",
CenterJustify		: "Centra",
RightJustify		: "Allinea a destra",
BlockJustify		: "Giustifica",
DecreaseIndent		: "Riduci rientro",
IncreaseIndent		: "Aumenta rientro",
Blockquote			: "Blockquote",	//MISSING
CreateDiv			: "Create Div Container",	//MISSING
EditDiv				: "Edit Div Container",	//MISSING
DeleteDiv			: "Remove Div Container",	//MISSING
Undo				: "Annulla",
Redo				: "Ripristina",
NumberedListLbl		: "Elenco numerato",
NumberedList		: "Inserisci/Modifica elenco numerato",
BulletedListLbl		: "Elenco puntato",
BulletedList		: "Inserisci/Modifica elenco puntato",
ShowTableBorders	: "Mostra bordi tabelle",
ShowDetails			: "Mostra dettagli",
Style				: "Stile",
FontFormat			: "Formato",
Font				: "Font",
FontSize			: "Dimensione",
TextColor			: "Colore testo",
BGColor				: "Colore sfondo",
Source				: "Codice Sorgente",
Find				: "Trova",
Replace				: "Sostituisci",
SpellCheck			: "Correttore ortografico",
UniversalKeyboard	: "Tastiera universale",
PageBreakLbl		: "Interruzione di pagina",
PageBreak			: "Inserisci interruzione di pagina",

Form			: "Modulo",
Checkbox		: "Checkbox",
RadioButton		: "Radio Button",
TextField		: "Campo di testo",
Textarea		: "Area di testo",
HiddenField		: "Campo nascosto",
Button			: "Bottone",
SelectionField	: "Menu di selezione",
ImageButton		: "Bottone immagine",

FitWindow		: "Massimizza l'area dell'editor",
ShowBlocks		: "Visualizza Blocchi",

// Context Menu
EditLink			: "Modifica collegamento",
CellCM				: "Cella",
RowCM				: "Riga",
ColumnCM			: "Colonna",
InsertRowAfter		: "Inserisci Riga Dopo",
InsertRowBefore		: "Inserisci Riga Prima",
DeleteRows			: "Elimina righe",
InsertColumnAfter	: "Inserisci Colonna Dopo",
InsertColumnBefore	: "Inserisci Colonna Prima",
DeleteColumns		: "Elimina colonne",
InsertCellAfter		: "Inserisci Cella Dopo",
InsertCellBefore	: "Inserisci Cella Prima",
DeleteCells			: "Elimina celle",
MergeCells			: "Unisce celle",
MergeRight			: "Unisci a Destra",
MergeDown			: "Unisci in Basso",
HorizontalSplitCell	: "Dividi Cella Orizzontalmente",
VerticalSplitCell	: "Dividi Cella Verticalmente",
TableDelete			: "Cancella Tabella",
CellProperties		: "Proprietà cella",
TableProperties		: "Proprietà tabella",
ImageProperties		: "Proprietà immagine",
FlashProperties		: "Proprietà Oggetto Flash",

AnchorProp			: "Proprietà ancora",
ButtonProp			: "Proprietà bottone",
CheckboxProp		: "Proprietà checkbox",
HiddenFieldProp		: "Proprietà campo nascosto",
RadioButtonProp		: "Proprietà radio button",
ImageButtonProp		: "Proprietà bottone immagine",
TextFieldProp		: "Proprietà campo di testo",
SelectionFieldProp	: "Proprietà menu di selezione",
TextareaProp		: "Proprietà area di testo",
FormProp			: "Proprietà modulo",

FontFormats			: "Normale;Formattato;Indirizzo;Titolo 1;Titolo 2;Titolo 3;Titolo 4;Titolo 5;Titolo 6;Paragrafo (DIV)",

// Alerts and Messages
ProcessingXHTML		: "Elaborazione XHTML in corso. Attendere prego...",
Done				: "Completato",
PasteWordConfirm	: "Il testo da incollare sembra provenire da Word. Desideri pulirlo prima di incollare?",
NotCompatiblePaste	: "Questa funzione è disponibile solo per Internet Explorer 5.5 o superiore. Desideri incollare il testo senza pulirlo?",
UnknownToolbarItem	: "Elemento della barra strumenti sconosciuto \"%1\"",
UnknownCommand		: "Comando sconosciuto \"%1\"",
NotImplemented		: "Comando non implementato",
UnknownToolbarSet	: "La barra di strumenti \"%1\" non esiste",
NoActiveX			: "Le impostazioni di sicurezza del tuo browser potrebbero limitare alcune funzionalità dell'editor. Devi abilitare l'opzione \"Esegui controlli e plug-in ActiveX\". Potresti avere errori e notare funzionalità mancanti.",
BrowseServerBlocked : "Non è possibile aprire la finestra di espolorazione risorse. Verifica che tutti i blocca popup siano bloccati.",
DialogBlocked		: "Non è possibile aprire la finestra di dialogo. Verifica che tutti i blocca popup siano bloccati.",
VisitLinkBlocked	: "It was not possible to open a new window. Make sure all popup blockers are disabled.",	//MISSING

// Dialogs
DlgBtnOK			: "OK",
DlgBtnCancel		: "Annulla",
DlgBtnClose			: "Chiudi",
DlgBtnBrowseServer	: "Cerca sul server",
DlgAdvancedTag		: "Avanzate",
DlgOpOther			: "<Altro>",
DlgInfoTab			: "Info",
DlgAlertUrl			: "Devi inserire l'URL",

// General Dialogs Labels
DlgGenNotSet		: "<non impostato>",
DlgGenId			: "Id",
DlgGenLangDir		: "Direzione scrittura",
DlgGenLangDirLtr	: "Da Sinistra a Destra (LTR)",
DlgGenLangDirRtl	: "Da Destra a Sinistra (RTL)",
DlgGenLangCode		: "Codice Lingua",
DlgGenAccessKey		: "Scorciatoia<br />da tastiera",
DlgGenName			: "Nome",
DlgGenTabIndex		: "Ordine di tabulazione",
DlgGenLongDescr		: "URL descrizione estesa",
DlgGenClass			: "Nome classe CSS",
DlgGenTitle			: "Titolo",
DlgGenContType		: "Tipo della risorsa collegata",
DlgGenLinkCharset	: "Set di caretteri della risorsa collegata",
DlgGenStyle			: "Stile",

// Image Dialog
DlgImgTitle			: "Proprietà immagine",
DlgImgInfoTab		: "Informazioni immagine",
DlgImgBtnUpload		: "Invia al server",
DlgImgURL			: "URL",
DlgImgUpload		: "Carica",
DlgImgAlt			: "Testo alternativo",
DlgImgWidth			: "Larghezza",
DlgImgHeight		: "Altezza",
DlgImgLockRatio		: "Blocca rapporto",
DlgBtnResetSize		: "Reimposta dimensione",
DlgImgBorder		: "Bordo",
DlgImgHSpace		: "HSpace",
DlgImgVSpace		: "VSpace",
DlgImgAlign			: "Allineamento",
DlgImgAlignLeft		: "Sinistra",
DlgImgAlignAbsBottom: "In basso assoluto",
DlgImgAlignAbsMiddle: "Centrato assoluto",
DlgImgAlignBaseline	: "Linea base",
DlgImgAlignBottom	: "In Basso",
DlgImgAlignMiddle	: "Centrato",
DlgImgAlignRight	: "Destra",
DlgImgAlignTextTop	: "In alto al testo",
DlgImgAlignTop		: "In Alto",
DlgImgPreview		: "Anteprima",
DlgImgAlertUrl		: "Devi inserire l'URL per l'immagine",
DlgImgLinkTab		: "Collegamento",

// Flash Dialog
DlgFlashTitle		: "Proprietà Oggetto Flash",
DlgFlashChkPlay		: "Avvio Automatico",
DlgFlashChkLoop		: "Cicla",
DlgFlashChkMenu		: "Abilita Menu di Flash",
DlgFlashScale		: "Ridimensiona",
DlgFlashScaleAll	: "Mostra Tutto",
DlgFlashScaleNoBorder	: "Senza Bordo",
DlgFlashScaleFit	: "Dimensione Esatta",

// Link Dialog
DlgLnkWindowTitle	: "Collegamento",
DlgLnkInfoTab		: "Informazioni collegamento",
DlgLnkTargetTab		: "Destinazione",

DlgLnkType			: "Tipo di Collegamento",
DlgLnkTypeURL		: "URL",
DlgLnkTypeAnchor	: "Ancora nella pagina",
DlgLnkTypeEMail		: "E-Mail",
DlgLnkProto			: "Protocollo",
DlgLnkProtoOther	: "<altro>",
DlgLnkURL			: "URL",
DlgLnkAnchorSel		: "Scegli Ancora",
DlgLnkAnchorByName	: "Per Nome",
DlgLnkAnchorById	: "Per id elemento",
DlgLnkNoAnchors		: "(Nessuna ancora disponibile nel documento)",
DlgLnkEMail			: "Indirizzo E-Mail",
DlgLnkEMailSubject	: "Oggetto del messaggio",
DlgLnkEMailBody		: "Corpo del messaggio",
DlgLnkUpload		: "Carica",
DlgLnkBtnUpload		: "Invia al Server",

DlgLnkTarget		: "Destinazione",
DlgLnkTargetFrame	: "<riquadro>",
DlgLnkTargetPopup	: "<finestra popup>",
DlgLnkTargetBlank	: "Nuova finestra (_blank)",
DlgLnkTargetParent	: "Finestra padre (_parent)",
DlgLnkTargetSelf	: "Stessa finestra (_self)",
DlgLnkTargetTop		: "Finestra superiore (_top)",
DlgLnkTargetFrameName	: "Nome del riquadro di destinazione",
DlgLnkPopWinName	: "Nome finestra popup",
DlgLnkPopWinFeat	: "Caratteristiche finestra popup",
DlgLnkPopResize		: "Ridimensionabile",
DlgLnkPopLocation	: "Barra degli indirizzi",
DlgLnkPopMenu		: "Barra del menu",
DlgLnkPopScroll		: "Barre di scorrimento",
DlgLnkPopStatus		: "Barra di stato",
DlgLnkPopToolbar	: "Barra degli strumenti",
DlgLnkPopFullScrn	: "A tutto schermo (IE)",
DlgLnkPopDependent	: "Dipendente (Netscape)",
DlgLnkPopWidth		: "Larghezza",
DlgLnkPopHeight		: "Altezza",
DlgLnkPopLeft		: "Posizione da sinistra",
DlgLnkPopTop		: "Posizione dall'alto",

DlnLnkMsgNoUrl		: "Devi inserire l'URL del collegamento",
DlnLnkMsgNoEMail	: "Devi inserire un'indirizzo e-mail",
DlnLnkMsgNoAnchor	: "Devi selezionare un'ancora",
DlnLnkMsgInvPopName	: "Il nome del popup deve iniziare con una lettera, e non può contenere spazi",

// Color Dialog
DlgColorTitle		: "Seleziona colore",
DlgColorBtnClear	: "Vuota",
DlgColorHighlight	: "Evidenziato",
DlgColorSelected	: "Selezionato",

// Smiley Dialog
DlgSmileyTitle		: "Inserisci emoticon",

// Special Character Dialog
DlgSpecialCharTitle	: "Seleziona carattere speciale",

// Table Dialog
DlgTableTitle		: "Proprietà tabella",
DlgTableRows		: "Righe",
DlgTableColumns		: "Colonne",
DlgTableBorder		: "Dimensione bordo",
DlgTableAlign		: "Allineamento",
DlgTableAlignNotSet	: "<non impostato>",
DlgTableAlignLeft	: "Sinistra",
DlgTableAlignCenter	: "Centrato",
DlgTableAlignRight	: "Destra",
DlgTableWidth		: "Larghezza",
DlgTableWidthPx		: "pixel",
DlgTableWidthPc		: "percento",
DlgTableHeight		: "Altezza",
DlgTableCellSpace	: "Spaziatura celle",
DlgTableCellPad		: "Padding celle",
DlgTableCaption		: "Intestazione",
DlgTableSummary		: "Indice",

// Table Cell Dialog
DlgCellTitle		: "Proprietà cella",
DlgCellWidth		: "Larghezza",
DlgCellWidthPx		: "pixel",
DlgCellWidthPc		: "percento",
DlgCellHeight		: "Altezza",
DlgCellWordWrap		: "A capo automatico",
DlgCellWordWrapNotSet	: "<non impostato>",
DlgCellWordWrapYes	: "Si",
DlgCellWordWrapNo	: "No",
DlgCellHorAlign		: "Allineamento orizzontale",
DlgCellHorAlignNotSet	: "<non impostato>",
DlgCellHorAlignLeft	: "Sinistra",
DlgCellHorAlignCenter	: "Centrato",
DlgCellHorAlignRight: "Destra",
DlgCellVerAlign		: "Allineamento verticale",
DlgCellVerAlignNotSet	: "<non impostato>",
DlgCellVerAlignTop	: "In Alto",
DlgCellVerAlignMiddle	: "Centrato",
DlgCellVerAlignBottom	: "In Basso",
DlgCellVerAlignBaseline	: "Linea base",
DlgCellRowSpan		: "Righe occupate",
DlgCellCollSpan		: "Colonne occupate",
DlgCellBackColor	: "Colore sfondo",
DlgCellBorderColor	: "Colore bordo",
DlgCellBtnSelect	: "Scegli...",

// Find and Replace Dialog
DlgFindAndReplaceTitle	: "Cerca e Sostituisci",

// Find Dialog
DlgFindTitle		: "Trova",
DlgFindFindBtn		: "Trova",
DlgFindNotFoundMsg	: "L'elemento cercato non è stato trovato.",

// Replace Dialog
DlgReplaceTitle			: "Sostituisci",
DlgReplaceFindLbl		: "Trova:",
DlgReplaceReplaceLbl	: "Sostituisci con:",
DlgReplaceCaseChk		: "Maiuscole/minuscole",
DlgReplaceReplaceBtn	: "Sostituisci",
DlgReplaceReplAllBtn	: "Sostituisci tutto",
DlgReplaceWordChk		: "Solo parole intere",

// Paste Operations / Dialog
PasteErrorCut	: "Le impostazioni di sicurezza del browser non permettono di tagliare automaticamente il testo. Usa la tastiera (Ctrl+X).",
PasteErrorCopy	: "Le impostazioni di sicurezza del browser non permettono di copiare automaticamente il testo. Usa la tastiera (Ctrl+C).",

PasteAsText		: "Incolla come testo semplice",
PasteFromWord	: "Incolla da Word",

DlgPasteMsg2	: "Incolla il testo all'interno dell'area sottostante usando la scorciatoia di tastiere (<STRONG>Ctrl+V</STRONG>) e premi <STRONG>OK</STRONG>.",
DlgPasteSec		: "A causa delle impostazioni di sicurezza del browser,l'editor non è in grado di accedere direttamente agli appunti. E' pertanto necessario incollarli di nuovo in questa finestra.",
DlgPasteIgnoreFont		: "Ignora le definizioni di Font",
DlgPasteRemoveStyles	: "Rimuovi le definizioni di Stile",

// Color Picker
ColorAutomatic	: "Automatico",
ColorMoreColors	: "Altri colori...",

// Document Properties
DocProps		: "Proprietà del Documento",

// Anchor Dialog
DlgAnchorTitle		: "Proprietà ancora",
DlgAnchorName		: "Nome ancora",
DlgAnchorErrorName	: "Inserici il nome dell'ancora",

// Speller Pages Dialog
DlgSpellNotInDic		: "Non nel dizionario",
DlgSpellChangeTo		: "Cambia in",
DlgSpellBtnIgnore		: "Ignora",
DlgSpellBtnIgnoreAll	: "Ignora tutto",
DlgSpellBtnReplace		: "Cambia",
DlgSpellBtnReplaceAll	: "Cambia tutto",
DlgSpellBtnUndo			: "Annulla",
DlgSpellNoSuggestions	: "- Nessun suggerimento -",
DlgSpellProgress		: "Controllo ortografico in corso",
DlgSpellNoMispell		: "Controllo ortografico completato: nessun errore trovato",
DlgSpellNoChanges		: "Controllo ortografico completato: nessuna parola cambiata",
DlgSpellOneChange		: "Controllo ortografico completato: 1 parola cambiata",
DlgSpellManyChanges		: "Controllo ortografico completato: %1 parole cambiate",

IeSpellDownload			: "Contollo ortografico non installato. Lo vuoi scaricare ora?",

// Button Dialog
DlgButtonText		: "Testo (Value)",
DlgButtonType		: "Tipo",
DlgButtonTypeBtn	: "Bottone",
DlgButtonTypeSbm	: "Invio",
DlgButtonTypeRst	: "Annulla",

// Checkbox and Radio Button Dialogs
DlgCheckboxName		: "Nome",
DlgCheckboxValue	: "Valore",
DlgCheckboxSelected	: "Selezionato",

// Form Dialog
DlgFormName		: "Nome",
DlgFormAction	: "Azione",
DlgFormMethod	: "Metodo",

// Select Field Dialog
DlgSelectName		: "Nome",
DlgSelectValue		: "Valore",
DlgSelectSize		: "Dimensione",
DlgSelectLines		: "righe",
DlgSelectChkMulti	: "Permetti selezione multipla",
DlgSelectOpAvail	: "Opzioni disponibili",
DlgSelectOpText		: "Testo",
DlgSelectOpValue	: "Valore",
DlgSelectBtnAdd		: "Aggiungi",
DlgSelectBtnModify	: "Modifica",
DlgSelectBtnUp		: "Su",
DlgSelectBtnDown	: "Gi",
DlgSelectBtnSetValue : "Imposta come predefinito",
DlgSelectBtnDelete	: "Rimuovi",

// Textarea Dialog
DlgTextareaName	: "Nome",
DlgTextareaCols	: "Colonne",
DlgTextareaRows	: "Righe",

// Text Field Dialog
DlgTextName			: "Nome",
DlgTextValue		: "Valore",
DlgTextCharWidth	: "Larghezza",
DlgTextMaxChars		: "Numero massimo di caratteri",
DlgTextType			: "Tipo",
DlgTextTypeText		: "Testo",
DlgTextTypePass		: "Password",

// Hidden Field Dialog
DlgHiddenName	: "Nome",
DlgHiddenValue	: "Valore",

// Bulleted List Dialog
BulletedListProp	: "Proprietà lista puntata",
NumberedListProp	: "Proprietà lista numerata",
DlgLstStart			: "Inizio",
DlgLstType			: "Tipo",
DlgLstTypeCircle	: "Tondo",
DlgLstTypeDisc		: "Disco",
DlgLstTypeSquare	: "Quadrato",
DlgLstTypeNumbers	: "Numeri (1, 2, 3)",
DlgLstTypeLCase		: "Caratteri minuscoli (a, b, c)",
DlgLstTypeUCase		: "Caratteri maiuscoli (A, B, C)",
DlgLstTypeSRoman	: "Numeri Romani minuscoli (i, ii, iii)",
DlgLstTypeLRoman	: "Numeri Romani maiuscoli (I, II, III)",

// Document Properties Dialog
DlgDocGeneralTab	: "Genarale",
DlgDocBackTab		: "Sfondo",
DlgDocColorsTab		: "Colori e margini",
DlgDocMetaTab		: "Meta Data",

DlgDocPageTitle		: "Titolo pagina",
DlgDocLangDir		: "Direzione scrittura",
DlgDocLangDirLTR	: "Da Sinistra a Destra (LTR)",
DlgDocLangDirRTL	: "Da Destra a Sinistra (RTL)",
DlgDocLangCode		: "Codice Lingua",
DlgDocCharSet		: "Set di caretteri",
DlgDocCharSetCE		: "Europa Centrale",
DlgDocCharSetCT		: "Cinese Tradizionale (Big5)",
DlgDocCharSetCR		: "Cirillico",
DlgDocCharSetGR		: "Greco",
DlgDocCharSetJP		: "Giapponese",
DlgDocCharSetKR		: "Coreano",
DlgDocCharSetTR		: "Turco",
DlgDocCharSetUN		: "Unicode (UTF-8)",
DlgDocCharSetWE		: "Europa Occidentale",
DlgDocCharSetOther	: "Altro set di caretteri",

DlgDocDocType		: "Intestazione DocType",
DlgDocDocTypeOther	: "Altra intestazione DocType",
DlgDocIncXHTML		: "Includi dichiarazione XHTML",
DlgDocBgColor		: "Colore di sfondo",
DlgDocBgImage		: "Immagine di sfondo",
DlgDocBgNoScroll	: "Sfondo fissato",
DlgDocCText			: "Testo",
DlgDocCLink			: "Collegamento",
DlgDocCVisited		: "Collegamento visitato",
DlgDocCActive		: "Collegamento attivo",
DlgDocMargins		: "Margini",
DlgDocMaTop			: "In Alto",
DlgDocMaLeft		: "A Sinistra",
DlgDocMaRight		: "A Destra",
DlgDocMaBottom		: "In Basso",
DlgDocMeIndex		: "Chiavi di indicizzazione documento (separate da virgola)",
DlgDocMeDescr		: "Descrizione documento",
DlgDocMeAuthor		: "Autore",
DlgDocMeCopy		: "Copyright",
DlgDocPreview		: "Anteprima",

// Templates Dialog
Templates			: "Modelli",
DlgTemplatesTitle	: "Contenuto dei modelli",
DlgTemplatesSelMsg	: "Seleziona il modello da aprire nell'editor<br />(il contenuto attuale verrà eliminato):",
DlgTemplatesLoading	: "Caricamento modelli in corso. Attendere prego...",
DlgTemplatesNoTpl	: "(Nessun modello definito)",
DlgTemplatesReplace	: "Cancella il contenuto corrente",

// About Dialog
DlgAboutAboutTab	: "Informazioni",
DlgAboutBrowserInfoTab	: "Informazioni Browser",
DlgAboutLicenseTab	: "Licenza",
DlgAboutVersion		: "versione",
DlgAboutInfo		: "Per maggiori informazioni visitare",

// Div Dialog
DlgDivGeneralTab	: "General",	//MISSING
DlgDivAdvancedTab	: "Advanced",	//MISSING
DlgDivStyle		: "Style",	//MISSING
DlgDivInlineStyle	: "Inline Style"	//MISSING
};
